# Retry Extended
[![Lint](https://github.com/strollby/retry-extended/actions/workflows/lint.yml/badge.svg?branch=main)](https://github.com/strollby/retry-extended/actions/workflows/lint.yml) [![Test Package](https://github.com/strollby/retry-extended/actions/workflows/test.yml/badge.svg)](https://github.com/strollby/retry-extended/actions/workflows/test.yml) [![Build Package](https://github.com/strollby/retry-extended/actions/workflows/build-main.yml/badge.svg?branch=main)](https://github.com/strollby/retry-extended/actions/workflows/build-main.yml) [![Publish to PyPI](https://github.com/strollby/retry-extended/actions/workflows/publish-release.yml/badge.svg?event=release)](https://github.com/strollby/retry-extended/actions/workflows/publish-release.yml)



Retry API compatible maintained project

This package had been developed on top of the original python [retry](https://github.com/invl/retry) package, and is intended to develop on top of it without implementing any breaking API changes and keeping the simplicity of the package.


### Roadmap
- [ ] Type Hints and Annotations & Clean up code
- [ ] Follow [Google Style guide](https://google.github.io/styleguide/pyguide.html)
- [ ] Async implementation for retry
